<?php
/*
* WP Image Protect - Settings File
* Settings API helper class
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
*  
*/



class wpipp_settings {


     //constructor
    function wpipp_settings() {
        global $wpipp_settings;

        //attempt to load premium file (not used for lite)
        include_once('wpipp-settings-premium.php');
        
        //initiliaze variables
        $wpipp_settings  = $this->plugin_initialize_options_array();  

        //add actions
        if (function_exists('add_action')) {
          add_action('admin_init', array( &$this, 'plugin_admin_init'));
          add_action('admin_menu', array( &$this, 'plugin_admin_add_page'));
        }
          
    }

     /**
     * enqueue the stylesheets
     */ 
    function wpipp_options_enqueue_scripts() {  
        wp_register_script( 'wpipp-script', plugins_url( '/js/wpipp-script.js' , dirname(__FILE__) ) , array('jquery','media-upload','thickbox') );  
        if(class_exists('wpipp_settings_premium')){
          wp_register_script( 'wpipp-script-premium', plugins_url( '/js/wpipp-script-premium.js' , dirname(__FILE__) ) , array('jquery','media-upload','thickbox') );  
        }
        wp_enqueue_script('jquery');  
        wp_enqueue_script('thickbox');  
        wp_enqueue_style('thickbox');  
        wp_enqueue_script('media-upload');  
        wp_enqueue_script('wpipp-script');  
        if(class_exists('wpipp_settings_premium')){
          wp_enqueue_script('wpipp-script-premium');
        }
          
    } 


     /**
     * return the settings
     */ 
    function plugin_initialize_options_array(){

          @include_once('wpipp-font-manager.php');
          //atempt to load font manager (premium plugin) else assign defaults
          if(class_exists('wpipp_font_manager')){
            $font_manager = new wpipp_font_manager();
            $font_list = $font_manager->get_font_list_array();
          } else {
            $font_list = array (
              '/Carrois_Gothic/CarroisGothic-Regular.ttf' => array ('path' => '/Carrois_Gothic/CarroisGothic-Regular.ttf', 'font_name' => 'CarroisGothic-Regular', 'licence_file' => plugins_url('/fonts/Carrois_Gothic/OFL.txt', dirname(__FILE__)) ),
              '/Erica_One/EricaOne-Regular.ttf' => array ('path' => '/Erica_One/EricaOne-Regular.ttf', 'font_name' => 'EricaOne-Regular', 'licence_file' => plugins_url('/fonts/Erica_One/OFL.txt', dirname(__FILE__)) ),
              '/Kite_One/KiteOne-Regular.ttf' => array ('path' => '/Kite_One/KiteOne-Regular.ttf', 'font_name' => 'KiteOne-Regular', 'licence_file' => plugins_url('/fonts/Kite_One/OFL.txt', dirname(__FILE__)) ),
              );
          }
          
          
          //if premium load premium values
          if(!function_exists('wpipp_premium_headings')){
            $group = __( "wpippDisplay", 'wpipp'); // define group
            $page_name = __( "wpipp_display", 'wpipp'); // eg media/discussion/reading or custom   
            $title = __( "WP Image Protect Lite Settings", 'wpipp');  // admin page title 
            $intro_text = __( "This page allows you to configure image watermarking and other settings for WP Image Protect Lite. The latest user documentation can be found on the <a href='http://8mediacentral.com/developments/wp-image-protect/wp-image-protect-premium-documentation/' title='Plugin documentation' target='_blank'>documentation page</a>.", 'wpipp'); // text displayed below title
            $nav_title = __( "WP Image Protect Settings", 'wpipp'); // name of page in context menu
          } else {
            $headings = wpipp_premium_headings();
            $group = $headings['group'];
            $page_name = $headings['page_name'];
            $title = $headings['title'];
            $intro_text = $headings['intro_text'];
            $nav_title = $headings['nav_title'];

          }
           
          /*  SECTIONS ARRAY
             * title: the title of the section
             * description: description of the section
             * fields: a array of field items key => array of options
              FIELD ARRAY OPTIONS
              * label: field label.
              * description: the field description displayed adjacent to the field. 
              * suffix: eg px, em, diplayed in italics adjacent to the field
              * default_value: default value of field when empty
              * dropdown: a drop down function, specify the drop down parameter name 
              * function: optional function to render field
              * onchange: option javascript call on dropdown change (currently only for dropdown items)
              * callback: optional function to validate field
              * field_class: the class to be assigned to the field
          */

           
          //if premium load premium values
          if(!function_exists('wpipp_premium_sections')){
             $sections = array(
              'wpipp_visible_watermark_settings' => array(
                  'title' => "Visible Watermark Settings",
                  'description' => __( "This section controls how visible watermarks appear on your content", 'wpipp'),
                  'fields' => array (
                    'visible_enabled' => array (
                        'label' => "Enabled",
                        'description' => __( "Sets the watermark option across the site", 'wpipp'),
                        'dropdown' => "dd_visible_option",
                        'onchange' => 'visible_enabled_change(this.value)',
                        'default_value' => "Text"
                        ),
                    'watermark_on_size' => array(
                        'label' => "Watermark only Size",
                        'description' => __( "Specify the minimum height or width of images before watermarks are applied", 'wpipp'),
                        'length' => "4",
                        'suffix' => "px",
                        'field_class' => 'wpipp_basic',
                        'default_value' => "300"
                        ),
                    'watermark_text' => array (
                        'label' => "Watermark Text",
                        'description' => __( "Text to display on images", 'wpipp'),
                        'field_class' => 'wpipp_text',
                        'default_value' => get_bloginfo(),
                        ),
                    'watermark_text_font' => array (
                        'label' => "Text Font",
                        'description' => __( "Name of font to be used", 'wpipp'),
                        'function' => 'plugin_font_dropdown',
                        'field_class' => 'wpipp_text',
                        'onchange' => 'font_change(this.id)',
                        'default_value' => key($font_list),
                        ),
                    'watermark_text_size' => array (
                        'label' => "Text Size",
                        'description' => __( "Font size of text", 'wpipp'),
                        'length' => "2",
                        'suffix' => "em",
                        'callback' => 'validate_text_size_entry',
                        'field_class' => 'wpipp_text',
                        'default_value' => "12"
                        ),
                    'watermark_text_colour' => array(
                        'label' => "Text Colour",
                        'description' => __( "Choose the display text colour you'd like", 'wpipp'),
                        'dropdown' => "dd_text_colour",
                        'field_class' => 'wpipp_text',
                        'default_value' => "#000"
                        ),
                    'watermark_text_border_width' => array (
                        'label' => "Text Margin",
                        'description' => __( "Size of the text border", 'wpipp'),
                        'length' => "5",
                        'suffix' => "px",
                        'callback' => 'validate_text_border_width_entry',
                        'field_class' => 'wpipp_text',
                        'default_value' => "5"
                        ),
                    'watermark_text_background_colour' => array (
                        'label' => "Background Colour",
                        'description' => __( "Colour of the text box", 'wpipp'),
                        'dropdown' => "dd_background_colour",                  
                        'field_class' => 'wpipp_text',
                        'default_value' => "#fff"
                        ),                
                    'watermark_position' => array(
                        'label' => "Watermark Position",
                        'description' => __( "Position of watermark on image", 'wpipp'),
                        'dropdown' => "dd_position",
                        'field_class' => 'wpipp_basic',
                        'default_value' => "br"
                        ),                
                    )
                  ),


                'wpipp_live_preview' => array(
                    'title' => 'Preview',
                    'description' => __( "Preview of how watermarks will appear on site images (click save changes to view)", 'wpipp'),
                    'fields' => array(
                      'watermark_live_preview' => array (
                        'label' => "Current Image Preview",
                        'description' => __( "How your watermark will appear on images", 'wpipp'),
                        'function' => 'wpipp_watermark_live_preview',
                        'default_value' =>  "NA"
                        ),
                      ),
                    ),
              );
          }  else {
              $sections = wpipp_premium_sections(); 
          }
          



           //Dropdown Options
          $dropdown_options = array (
              'dd_text_colour' => array (
                  '#f00' => __( "Red", 'wpipp') ,
                  '#0f0' => __( "Green", 'wpipp'),
                  '#00f' => __( "Blue", 'wpipp'),
                  '#fff' => __( "White", 'wpipp'),
                  '#000' => __( "Black", 'wpipp'),
                  '#aaa' => __( "Gray", 'wpipp'),
                  ),
              'dd_background_colour' => array (
                  'none' => __( "Transparent (None)", 'wpipp') ,
                  '#f00' => __( "Red", 'wpipp') ,
                  '#0f0' => __( "Green", 'wpipp'),
                  '#00f' => __( "Blue", 'wpipp'),
                  '#fff' => __( "White", 'wpipp'),
                  '#000' => __( "Black", 'wpipp'),
                  '#aaa' => __( "Gray", 'wpipp'),
                  ),
              'dd_position' => array (
                  'tl' => __( "Top Left", 'wpipp'),
                  'tc' => __( "Top Middle", 'wpipp'),
                  'tr' => __( "Top Right", 'wpipp'),
                  'cl' => __( "Middle Left", 'wpipp'),
                  'cc' => __( "Middle", 'wpipp'),
                  'cr' => __( "Middle Right", 'wpipp'),
                  'bl' => __( "Bottom Left", 'wpipp'),
                  'bc' => __( "Bottom Middle", 'wpipp'),
                  'br' => __( "Bottom Right", 'wpipp'),
                  'rp' => __( "Tile X and Y", 'wpipp'),
                  ),
              'dd_boolean' => array (
                  'true' => __( "Enabled", 'wpipp'),
                  'false' => __( "Disabled", 'wpipp'),
                  ),
              'dd_render' => array (
                  'JPG' => __( "JPG", 'wpipp'),
                  'PNG' => __( "PNG", 'wpipp'),
                  ),
              );
            
            
            if(!function_exists('wpipp_premium_visible_options')){
              $dropdown_options['dd_visible_option'] = array (
                  'none' => __( "None", 'wpipp'),
                  'text' => __( "Text", 'wpipp'),
                  );
            } else {
              $dropdown_options['dd_visible_option'] = wpipp_premium_visible_options();
            }
            


          $vars = array(
                'group' => $group,
                'page_name' => $page_name,
                'title' => $title,
                'intro_text' => $intro_text,
                'nav_title' => $nav_title,
                'sections' => $sections,
                'dropdown_options' => $dropdown_options,
                'font_list' => $font_list
              );


          return $vars;

         

    }
     
      /**
     * add this page to the Settings tab in the admin panel
     */ 
    function plugin_admin_add_page() {
      global $wpipp_settings;
      $page_name = add_options_page($wpipp_settings['title'], $wpipp_settings['nav_title'], 'manage_options', $wpipp_settings['page_name'], array( &$this,'plugin_options_page'));

      // Using registered $page handle to hook script load
      add_action('admin_print_scripts-' . $page_name, array( &$this, 'wpipp_options_enqueue_scripts'));
    }
     

     /**
     * load the options page
     */ 
    function plugin_options_page() {
      global $wpipp_settings;
      printf('</pre>
      <div class = "wrap">
      <div id="icon-options-general" class="icon32"><br /></div>
      <h2>%s</h2>
      <p>%s</p>
      <form action="options.php" method="post">',$wpipp_settings['title'],$wpipp_settings['intro_text']);
       settings_fields($wpipp_settings['group']);
       do_settings_sections($wpipp_settings['page_name']);
       printf('<input type="submit" name="Submit" value="%s" /></form></div>
      <pre>
      ',__('Save Changes'));
    }
    
    /**
     * add the settings
     */ 
    function plugin_admin_init(){
      global $wpipp_settings;
      foreach ($wpipp_settings["sections"] AS $section_key=>$section_value) :
        add_settings_section($section_key, $section_value['title'], array( &$this, 'plugin_section_text'), $wpipp_settings['page_name'], $section_value);
        foreach ($section_value['fields'] AS $field_key=>$field_value) :
          $function = (!empty($field_value['dropdown'])) ? array( &$this, 'plugin_setting_dropdown' ) : array( &$this, 'plugin_setting_string' );
          $function = (!empty($field_value['function'])) ? array( &$this,  $field_value['function'] ) : $function;
          $callback = (!empty($field_value['callback'])) ? array( &$this,  $field_value['callback'] ) : NULL;
          add_settings_field($wpipp_settings['group'].'_'.$field_key, $field_value['label'], $function, $wpipp_settings['page_name'], $section_key,array_merge($field_value,array('name' => $wpipp_settings['group'].'_'.$field_key)));
          register_setting($wpipp_settings['group'], $wpipp_settings['group'].'_'.$field_key,$callback);
          endforeach;
        endforeach;
    }
     
     /**
     * add options to wordpress options API for the WP Image Protect Premium Plugin
     * initialize these options
     */
     function wpipp_add_options(){
      
      global $wpipp_settings;
      foreach ($wpipp_settings["sections"] AS $section_key=>$section_value) :
        foreach ($section_value['fields'] AS $field_key=>$field_value) :
          add_option($wpipp_settings['group'].'_'.$field_key, array("text_string" => $field_value['default_value']));
          endforeach;
        endforeach; 

      //update options for versions etc.
      update_option('wpipp_version', WPIPP_VERSION);
      update_option('wpipp_mode', WPIPP_MODE);
      update_option('wpipp_textdomain', WPIPP_TEXTDOMAIN);  
      update_option('wpipp_active', true);    
    }

    /**
     * remove options from wordpress options API for the WP Image Protect Premium Plugin
     */
    function wpipp_remove_options(){
      global $wpipp_settings;

      /* As of v0.83 - settings no longer deleted */
      /*
      foreach ($wpipp_settings["sections"] AS $section_key=>$section_value) :
        foreach ($section_value['fields'] AS $field_key=>$field_value) :
          delete_option($wpipp_settings['group'].'_'.$field_key);
          endforeach;
        endforeach; 
      */

      delete_option('wpipp_version');
      delete_option('wpipp_mode');
      delete_option('wpipp_textdomain');
      delete_option('wpipp_active');
    }


    function plugin_section_text($value = NULL) {
      global $wpipp_settings;
      printf("
    %s
     
    ",$wpipp_settings['sections'][$value['id']]['description']);
    }
     

    /*
    * Renderer for a standard string option
    */  
    function plugin_setting_string($value = NULL) {
      $options = get_option($value['name']);

      //special case for 0 string use asci &#48;
      $default_value = (!empty ($value['default_value'])) ? $value['default_value'] : "&#48;";
      printf('<input id="%s" type="text" name="%1$s[text_string]" class="%2$s" value="%3$s" size="40" /> %4$s %5$s',
        $value['name'],
        (!empty ($value['field_class'])) ? $value['field_class'] : NULL,
        (!empty ($options['text_string'])) ? $options['text_string'] : $default_value,
        (!empty ($value['suffix'])) ? $value['suffix'] : NULL,
        (!empty ($value['description'])) ? sprintf("<em>%s</em>",$value['description']) : NULL);
    }
     

     /*
     * Renderer for a dropdown option
     */
    function plugin_setting_dropdown($value = NULL) {
      global $wpipp_settings;
      $options = get_option($value['name']);
      $default_value = (!empty ($value['default_value'])) ? $value['default_value'] : NULL;
      $onchange = (!empty ($value['onchange'])) ? $value['onchange'] : NULL;
      $current_value = ($options['text_string']) ? $options['text_string'] : $default_value;
        $chooseFrom = "";
        $choices = $wpipp_settings['dropdown_options'][$value['dropdown']];
      foreach($choices AS $key=>$option) :
        $chooseFrom .= sprintf('<option value="%s" %s>%s</option>',
          $key,($current_value == $key ) ? ' selected="selected"' : NULL,$option);
        endforeach;
        printf('
    <select id="%s" name="%1$s[text_string]" class="%2$s" onchange="%3$s" >%4$s</select>
    %5$s',$value['name'], (!empty ($value['field_class'])) ? $value['field_class'] : NULL, $onchange, $chooseFrom,
      (!empty ($value['description'])) ? sprintf("<em>%s</em>",$value['description']) : NULL);
    }


      /*
     * Renderer for font dropdown option
     */
    function plugin_font_dropdown($value = NULL) {
      global $wpipp_settings;
      $options = get_option($value['name']);
      $default_value = (!empty ($value['default_value'])) ? $value['default_value'] : NULL;
      $onchange = (!empty ($value['onchange'])) ? $value['onchange'] : NULL;
      $current_value = ($options['text_string']) ? $options['text_string'] : $default_value;
        $chooseFrom = "";
        $choices = $wpipp_settings['font_list'];
      foreach($choices AS $key=>$option) :
        $chooseFrom .= sprintf('<option value="%s" id="%4$s" licence_url="%2$s" %3$s>%4$s</option>',
          $key,  $option['licence_file'], ($current_value == $key ) ? ' selected="selected"' : NULL, $option['font_name']);
        if($current_value == $key ){
          //set current licence file url for selected item
          $licence_file_url = $option['licence_file'];
        }
        endforeach;
        printf('
    <select id="%s" name="%1$s[text_string]" class="%2$s" onchange="%3$s" >%4$s</select>
    %5$s   (<a id="licence_url" href="%6$s" target="_blank">Click to view font licence</a>)',$value['name'], (!empty ($value['field_class'])) ? $value['field_class'] : NULL, $onchange, $chooseFrom,
      (!empty ($value['description'])) ? sprintf("<em>%s</em>",$value['description']) : NULL, $licence_file_url);
    }

    /*
    * Renderer for the watermark image selector
    */
    function wpipp_watermark_image($value = NULL) {  
      if(function_exists('wpipp_watermark_image_premium')){
          wpipp_watermark_image_premium($value);
        }
    } 


    /*
    * Renderer for the uploaded watermark image preview
    */
    function wpipp_uploaded_watermark_preview($value = NULL) {  
        if(function_exists('wpipp_uploaded_watermark_preview_premium')) {
          wpipp_uploaded_watermark_preview_premium($value);
        }
    } 


      /*
      * Renderer for the watermark live image preview
      */
      function wpipp_watermark_live_preview() {  
          global $wpipp_settings;
          //set the preview url to that of the rendering proxy
          $preview_url = plugins_url( '/php/wpipp-image-manager.php' , dirname(__FILE__) );
             ?>  
          <div id="live_matwatermark_preview" style="min-height: 100px;">  
              <img style="max-width:100%;" src="<?php echo esc_url( $preview_url ); ?>" />  
          </div>
          <?php  
      } 


    /*
    * validation for image url
    */
    function validate_watermark_image_url($input){
      return $input;
    }

    /*
    * validation for image preview - dummy method
    */
    function validate_watermark_image_preview($input){
      if($_POST['delete_watermark_image_button']){
        add_settings_error( 'Alert', 'delete_watermark_pressed', 'Delete button pressed' );
        $this->wpipp_reset_option('wpipp_watermark_image_url');
      }
      return $input;
    }


    /*
    * validation for image transparency
    */
    function validate_transparency_value($input){
      global $wpipp_settings;
      //get current value to reset to
      $current_value = $this->get_wpipp_option_from_wp('watermark_transparency');
      $input_string = (!empty ($input['text_string'])) ? $input['text_string'] : NULL;
      if(is_null($input_string)){
        //input is 0 - as expected
        return $input;
      }elseif(!is_numeric($input_string)){
        add_settings_error( 'watermark_transparency', 'int_not_valid', 'Transparency must be a value between 0 and 100' );
        return $current_value;
      }  elseif(intval($input_string)<0){
        add_settings_error( 'watermark_transparency', 'int_too_small', 'Transparency cannot be less than 0' );
        return $current_value;
      } elseif(intval($input_string)>100){
        add_settings_error( 'watermark_transparency', 'int_too_large', 'Transparency cannot be greater than 100' );
        return $current_value;
      } else {
        return $input;
      }
      
    }

    /*
    * validation for cache option 
    */
    function validate_cache_option($input){
      if(function_exists('validate_cache_option_premium')){
        return validate_cache_option_premium($input);
      } else {
        return $input;
      }
    }

    /**
    * validate text size
    */
    function validate_text_size_entry($input){
      global $wpipp_settings;
      //get current value to reset to
      $current_value = $this->get_wpipp_option_from_wp('watermark_text_size');
      $input_string = (!empty ($input['text_string'])) ? $input['text_string'] : NULL;
      if(is_null($input_string)){
        //input is 0 - as expected
        return $input;
      }elseif(!is_numeric($input_string)){
        add_settings_error( 'watermark_text_size', 'int_not_valid', 'Text Size must be between 5 and 50 px' );
        return $current_value;
      }  elseif(intval($input_string)<5){
        add_settings_error( 'watermark_text_size', 'int_too_small', 'Text Size cannot be less than 5px' );
        return $current_value;
      } elseif(intval($input_string)>50){
        add_settings_error( 'watermark_text_size', 'int_too_large', 'Text Size cannot be greater 50px' );
        return $current_value;
      } else {
        return $input;
      }

    }


    /**
    * validate watermark text border width
    */
    function validate_text_border_width_entry($input){
      global $wpipp_settings;
      //get current value to reset to
      $current_value = $this->get_wpipp_option_from_wp('watermark_text_border_width');
      $input_string = (!empty ($input['text_string'])) ? $input['text_string'] : NULL;
      if(is_null($input_string)){
        //input is 0 - as expected
        return $input;
      }elseif(!is_numeric($input_string)){
        add_settings_error( 'watermark_text_border_width', 'int_not_valid', 'Text Border Width must be between 5 and 50 px' );
        return $current_value;
      }  elseif(intval($input_string)<0){
        add_settings_error( 'watermark_text_border_width', 'int_too_small', 'Text Border Width cannot be less than 0px' );
        return $current_value;
      } elseif(intval($input_string)>50){
        add_settings_error( 'watermark_text_border_width', 'int_too_large', 'Text Border Width cannot be greater 50px' );
        return $current_value;
      } else {
        return $input;
      }

    }


    /*
    * return the current value that option is specified in the wp options table
    */

    function get_wpipp_option_value_from_wp($option_name){
      global $wpipp_settings;
      
      $real_option_value_array = $this->get_wpipp_option_from_wp($option_name);
      $real_option_value_text_string  = $real_option_value_array['text_value'];
      return $real_option_value_text_string;
    }

    function get_wpipp_option_from_wp($option_name){
      global $wpipp_settings;
      //the real option name is prefixed with the group name
      $real_option_name = $wpipp_settings['group'] . "_" . $option_name;
      $real_option_value_array = get_option($real_option_name);
      return $real_option_value_array;
    }

    /**
     * reset an option to the original value
     */
     function wpipp_reset_option($option_name){
      
      global $wpipp_settings;
      foreach ($wpipp_settings["sections"] AS $section_key=>$section_value) :
        foreach ($section_value['fields'] AS $field_key=>$field_value) :
          if($field_key==$option_name){
            update_option($wpipp_settings['group'].'_'.$field_key, array("text_string" => $field_value['default_value']));
          }
          
          endforeach;
        endforeach; 
        
    }


 
//end class
}
 
$wpipp_settings_init = new wpipp_settings();
?>